"""collective.formcriteria.criteria"""

from collective.formcriteria.criteria import simplestring
simplestring # import to register

from collective.formcriteria.criteria import list as list_
list_ # import to register

from collective.formcriteria.criteria import selection
selection # import to register

from collective.formcriteria.criteria import checkbox
checkbox # import to register

from collective.formcriteria.criteria import daterange
daterange # import to register
